@@ -1,17 +1,16 @@
 # src/anyads/__init__.py
 
-from .client import PollingSDK, init, get_sdk_instance
+from .client import AnyAdsSDK, init, get_sdk_instance
 from .exceptions import AnyAdsException, InitializationError, APIError
 
 
 __all__ = [
-    "PollingSDK",
+    "AnyAdsSDK",
     "init",
     "get_sdk_instance",
     "AnyAdsException",
     "InitializationError",
     "APIError",
-    "integrations",
 ]
 
 import logging
