@@ -11,23 +11,22 @@ import httpx
 from getmac import get_mac_address
 
 from .exceptions import InitializationError, APIError
+from .post import PostHandler
+from .task import TaskHandler
 
 logger = logging.getLogger("anyads.sdk")
 
-BroadcastHandler = Callable[[Dict[str, Any]], Coroutine[Any, Any, None]]
+_sdk_instance: Optional['AnyAdsSDK'] = None
 
-_sdk_instance: Optional['PollingSDK'] = None
-
-class PollingSDK:
-    def __init__(self, api_key: str, interval_seconds: int = 300, sdk_version: str = "py-0.1.3"):
+class AnyAdsSDK:
+    def __init__(self, api_key: str, sdk_version: str = "py-1.0.0"):
         if hasattr(self, '_initialized'):
             return
 
         if not api_key or not api_key.startswith("anyads_"):
-            raise InitializationError("Неверный формат API ключа. Он должен начинаться с 'anyads_'.")
+            raise InitializationError("Неверный формат API ключа.")
         
         self.api_key = api_key
-        self.interval = interval_seconds
         self.sdk_version = sdk_version
         self.api_base_url = "https://api.anyads.online/v1"
         self._instance_id_path = Path("./.anyads_instance_id")
@@ -35,15 +34,16 @@ class PollingSDK:
         self._fingerprint = self._get_environment_fingerprint()
         
         self._http_client: Optional[httpx.AsyncClient] = None
-        
-        self._polling_task: Optional[asyncio.Task] = None
-        self._broadcast_handler: Optional[BroadcastHandler] = None
-        self._initialized = True
-        
         self._instance_id: Optional[str] = None
+        self._capabilities_task: Optional[asyncio.Task] = None
+        
+        self.posts = PostHandler(self)
+        self.tasks = TaskHandler(self)
+        
+        self._initialized = True
 
     async def _initialize_session(self):
-        """Асинхронная инициализация, включая создание InstanceID и HTTP клиента."""
+        """Асинхронная инициализация, создает InstanceID и HTTP клиент."""
         if self._instance_id is None:
             self._instance_id = await self._get_or_create_instance_id()
         
@@ -56,8 +56,7 @@ class PollingSDK:
                     "X-Environment-Fingerprint": self._fingerprint,
                     "User-Agent": f"AnyAdsPythonSDK/{self.sdk_version}",
                 },
-                timeout=20.0,
-                follow_redirects=True,
+                timeout=20.0
             )
         logger.info(f"SDK AnyAds инициализирован. Instance ID: {self._instance_id}")
 
@@ -78,7 +77,7 @@ class PollingSDK:
             return new_id
         except Exception as e:
             raise InitializationError(f"Не удалось прочитать, записать или зарегистрировать Instance ID: {e}")
-
+        
     async def _register_instance(self, instance_id: str):
         """Отправляет запрос на регистрацию нового инстанса на сервер."""
         try:
@@ -101,7 +100,6 @@ class PollingSDK:
             logger.critical(f"Сетевая ошибка при регистрации Instance ID: {e}")
             raise APIError(f"Сетевая ошибка регистрации инстанса") from e
 
-
     def _get_environment_fingerprint(self) -> str:
         try:
             mac = get_mac_address()
@@ -113,54 +111,6 @@ class PollingSDK:
             logger.warning(f"Не удалось сгенерировать полный отпечаток системы: {e}")
             return "fingerprint_generation_failed"
 
-    async def _poll(self):
-        """Основной цикл опроса Ad Engine."""
-        await asyncio.sleep(5)
-        while True:
-            try:
-                logger.debug("Проверка наличия рекламных задач...")
-                if not self._http_client:
-                    raise InitializationError("HTTP клиент не инициализирован.")
-
-                response = await self._http_client.get(
-                    "/tasks/bots/newsletters",
-                    params={"sdk_version": self.sdk_version}
-                )
-
-                if update_header := response.headers.get("X-AnyAds-Update-Recommended"):
-                    logger.warning(f"Доступна новая версия SDK: {update_header}. Пожалуйста, обновитесь: pip install --upgrade anyads")
-
-                if response.status_code == 200:
-                    ad_task = response.json()
-                    if self._broadcast_handler:
-                        logger.info(f"Получена новая рекламная задача: {ad_task.get('task_id')}")
-                        asyncio.create_task(self._broadcast_handler(ad_task))
-                    else:
-                        logger.warning("Получена рекламная задача, но не зарегистрирован обработчик (on_broadcast_received). Задача будет проигнорирована.")
-                elif response.status_code == 204:
-                    logger.debug("Нет активных задач.")
-                else:
-                    response.raise_for_status()
-
-            except httpx.HTTPStatusError as e:
-                if e.response.status_code == 426:
-                    logger.critical("Ваша версия SDK критически устарела и больше не поддерживается! Пожалуйста, обновитесь: pip install --upgrade anyads. Опрос остановлен.")
-                    break
-                logger.error(f"Ошибка API при опросе: {e.response.status_code} - {e.response.text}")
-            except httpx.RequestError as e:
-                logger.error(f"Сетевая ошибка при опросе Ad Engine: {e}")
-            except Exception as e:
-                logger.error(f"Непредвиденная ошибка в цикле опроса: {e}", exc_info=True)
-            
-            await asyncio.sleep(self.interval)
-
-    def on_broadcast_received(self, handler: BroadcastHandler):
-        """Декоратор для регистрации коллбэка."""
-        if not asyncio.iscoroutinefunction(handler):
-            raise TypeError("Обработчик должен быть асинхронной функцией (async def).")
-        self._broadcast_handler = handler
-        return handler
-
     async def process_verification_code(self, code: str) -> bool:
         """Отправляет верификационный код на сервер."""
         if not self._http_client:
@@ -184,36 +134,53 @@ class PollingSDK:
             logger.error(f"Ошибка при отправке кода верификации: {e}")
             return False
 
+    async def _manage_polling_loops(self):
+        """Периодически проверяет возможности площадки и запускает/останавливает нужные опросы."""
+        while True:
+            try:
+                logger.debug("Проверка возможностей площадки...")
+                response = await self._http_client.get("/platform/capabilities")
+                response.raise_for_status()
+                capabilities = response.json()
+
+                if capabilities.get("accepts_newsletters"):
+                    self.posts._start_polling()
+                else:
+                    self.posts._stop_polling()
+
+                self.tasks._set_enabled(capabilities.get("accepts_tasks", False))
+
+            except Exception as e:
+                logger.error(f"Ошибка при проверке возможностей платформы: {e}")
+            
+            await asyncio.sleep(3600)
+
     async def start(self):
-        """Инициализирует сессию и запускает фоновый опрос."""
+        """Инициализирует сессию и запускает менеджер опросов."""
         await self._initialize_session()
-        if self._polling_task and not self._polling_task.done():
-            logger.warning("Фоновый опрос уже запущен.")
+        if self._capabilities_task and not self._capabilities_task.done():
+            logger.warning("Менеджер опросов уже запущен.")
             return
-        self._polling_task = asyncio.create_task(self._poll())
+        self._capabilities_task = asyncio.create_task(self._manage_polling_loops())
 
     async def stop(self):
-        """Останавливает фоновый опрос и закрывает соединения."""
-        if self._polling_task:
-            self._polling_task.cancel()
-            try:
-                await self._polling_task
-            except asyncio.CancelledError:
-                pass
-            self._polling_task = None
+        """Останавливает все фоновые задачи и закрывает соединения."""
+        if self._capabilities_task:
+            self._capabilities_task.cancel()
+        
+        self.posts._stop_polling()
+        
         if self._http_client:
             await self._http_client.aclose()
         logger.info("SDK AnyAds остановлен.")
 
-def init(api_key: str, interval_seconds: int = 300, sdk_version: str = "py-0.1.0") -> PollingSDK:
-    """Инициализирует и возвращает глобальный экземпляр SDK."""
+def init(api_key: str, sdk_version: str = "py-1.0.0") -> AnyAdsSDK:
     global _sdk_instance
     if _sdk_instance is None:
-        _sdk_instance = PollingSDK(api_key, interval_seconds, sdk_version)
+        _sdk_instance = AnyAdsSDK(api_key, sdk_version)
     return _sdk_instance
 
-def get_sdk_instance() -> PollingSDK:
-    """Возвращает инициализированный экземпляр SDK."""
+def get_sdk_instance() -> AnyAdsSDK:
     if _sdk_instance is None:
-        raise InitializationError("SDK не был инициализирован. Вызовите anyads.init() при старте вашего приложения.")
+        raise InitializationError("SDK не был инициализирован. Вызовите anyads.init() при старте.")
     return _sdk_instance
\ No newline at end of file
